@@ -124,7 +124,9 @@ default_unit_symbol_lut = OrderedDict(
             (1.0, dimensions.luminous_flux / dimensions.area, 0.0, r"\rm{lx}", True),
         ),
         ("degC", (1.0, dimensions.temperature, -273.15, r"^\circ\rm{C}", True)),
+        ("delta_degC", (1.0, dimensions.temperature, 0, r"\Delta^\circ\rm{C}", True)),
         # Imperial and other non-metric units
+        ("mil", (1e-3 * m_per_inch, dimensions.length, 0.0, r"\rm{mil}", False)),
         ("inch", (m_per_inch, dimensions.length, 0.0, r"\rm{in}", False)),
         ("ft", (m_per_ft, dimensions.length, 0.0, r"\rm{ft}", False)),
         ("yd", (0.9144, dimensions.length, 0.0, r"\rm{yd}", False)),
@@ -140,6 +142,16 @@ default_unit_symbol_lut = OrderedDict(
                 False,
             ),
         ),
+        (
+            "delta_degF",
+            (
+                kelvin_per_rankine,
+                dimensions.temperature,
+                0.0,
+                r"\Delta^\circ\rm{F}",
+                False,
+            ),
+        ),
         (
             "R",
             (kelvin_per_rankine, dimensions.temperature, 0.0, r"^\circ\rm{R}", False),
@@ -154,6 +166,16 @@ default_unit_symbol_lut = OrderedDict(
                 False,
             ),
         ),
+        (
+            "kip",
+            (
+                1000 * kg_per_pound * standard_gravity_m_per_s2,
+                dimensions.force,
+                0.0,
+                r"\rm{kip}",
+                False,
+            ),
+        ),
         ("lb", (kg_per_pound, dimensions.mass, 0.0, r"\rm{lb}", False)),
         ("atm", (pascal_per_atm, dimensions.pressure, 0.0, r"\rm{atm}", False)),
         ("hp", (watt_per_horsepower, dimensions.power, 0.0, r"\rm{hp}", False)),
@@ -181,6 +203,16 @@ default_unit_symbol_lut = OrderedDict(
                 False,
             ),
         ),
+        (
+            "ksi",
+            (
+                1000 * kg_per_pound * standard_gravity_m_per_s2 / m_per_inch ** 2,
+                dimensions.pressure,
+                0.0,
+                r"\rm{ksi}",
+                False,
+            ),
+        ),
         ("smoot", (1.7018, dimensions.length, 0.0, r"\rm{smoot}", False)),
         # dimensionless stuff
         ("dimensionless", (1.0, dimensions.dimensionless, 0.0, r"", False)),
@@ -423,6 +455,7 @@ default_unit_name_alternatives = OrderedDict(
         ("lx", ("lux",)),
         ("degC", ("degree_celsius", "degree_Celsius", "celcius", "celsius", "°C")),
         # Imperial and other non-metric units
+        ("mil", ("thou", "thousandth")),
         ("inch", ("in",)),
         ("ft", ("foot",)),
         ("yd", ("yard",)),
@@ -430,6 +463,7 @@ default_unit_name_alternatives = OrderedDict(
         ("degF", ("degree_fahrenheit", "degree_Fahrenheit", "fahrenheit", "°F")),
         ("R", ("degree_rankine", "rankine")),
         ("lbf", ("pound_force",)),
+        ("kip", ("kilopound", "kipf")),
         ("lb", ("pound", "pound_mass", "lbm")),
         ("atm", ("atmosphere",)),
         ("hp", ("horsepower",)),
@@ -437,6 +471,7 @@ default_unit_name_alternatives = OrderedDict(
         ("cal", ("calorie",)),
         ("BTU", ("british_thermal_unit",)),
         ("psi", ("pounds_per_square_inch",)),
+        ("ksi", ("kips_per_square_inch",)),
         # dimensionless stuff
         ("dimensionless", ("_", "")),
         ("B", ("bel",)),
