@@ -123,6 +123,7 @@ from unyt.exceptions import (
     UnitOperationError,
     UnitConversionError,
     UnitsNotReducible,
+    SymbolNotFoundError,
 )
 from unyt.equivalencies import equivalence_registry
 from unyt._on_demand_imports import _astropy, _pint
@@ -160,11 +161,32 @@ def _sqrt_unit(unit):
 
 @lru_cache(maxsize=128, typed=False)
 def _multiply_units(unit1, unit2):
-    ret = (unit1 * unit2).simplify()
+    try:
+        ret = (unit1 * unit2).simplify()
+    except SymbolNotFoundError:
+        # Some operators are not natively commutative when operands are
+        # defined within different unit registries, and conversion
+        # is defined one way but not the other.
+        ret = (unit2 * unit1).simplify()
     return ret.as_coeff_unit()
 
 
+TEMPERATURE_WARNING = """
+    Ambiguous operation with heterogeneous temperature units.
+    In the future, such operations will generate UnitOperationError.
+    Use delta_degC or delta_degF to avoid the ambiguity.
+"""
+
+
+@lru_cache(maxsize=128, typed=False)
 def _preserve_units(unit1, unit2=None):
+    if unit2 is None or unit1.dimensions is not temperature:
+        return 1, unit1
+    if unit1.base_offset == 0.0 and unit2.base_offset != 0.0:
+        if str(unit1.expr) in ["K", "R"]:
+            warnings.warn(TEMPERATURE_WARNING, FutureWarning, stacklevel=3)
+            return 1, unit1
+        return 1, unit2
     return 1, unit1
 
 
@@ -180,7 +202,10 @@ def _square_unit(unit):
 
 @lru_cache(maxsize=128, typed=False)
 def _divide_units(unit1, unit2):
-    ret = (unit1 / unit2).simplify()
+    try:
+        ret = (unit1 / unit2).simplify()
+    except SymbolNotFoundError:
+        ret = (1 / (unit2 / unit1).simplify()).units
     return ret.as_coeff_unit()
 
 
@@ -1408,7 +1433,7 @@ class unyt_array(np.ndarray):
         data = dataset[:]
         units = dataset.attrs.get("units", "")
         unit_lut = default_unit_symbol_lut.copy()
-        unit_lut_load = pickle.loads(dataset.attrs["unit_registry"].tostring())
+        unit_lut_load = pickle.loads(dataset.attrs["unit_registry"].tobytes())
         unit_lut.update(unit_lut_load)
         f.close()
         registry = UnitRegistry(lut=unit_lut, add_default_symbols=False)
