@@ -28,6 +28,7 @@ import pickle
 import pytest
 from sympy import Symbol
 
+from unyt.array import unyt_quantity
 from unyt.testing import assert_allclose_units
 from unyt.unit_registry import UnitRegistry
 from unyt.dimensions import (
@@ -857,6 +858,11 @@ def test_degC():
     assert str(a) == "1 °C"
 
 
+def test_delta_degC():
+    a = 1 * Unit("delta_degC")
+    assert str(a) == "1 Δ°C"
+
+
 def test_degF():
     assert Unit("degree_fahrenheit") == Unit("degF")
     assert Unit("degree_Fahrenheit") == Unit("degF")
@@ -864,3 +870,22 @@ def test_degF():
     assert Unit("°F") == Unit("degF")
     a = 1 * Unit("degF")
     assert str(a) == "1 °F"
+
+
+def test_delta_degF():
+    a = 1 * Unit("delta_degF")
+    assert str(a) == "1 Δ°F"
+
+
+def test_mixed_registry_operations():
+
+    reg = UnitRegistry(unit_system="cgs")
+    reg.add("fake_length", 0.001, length)
+    a = unyt_quantity(1, units="fake_length", registry=reg)
+    b = unyt_quantity(1, "cm")
+
+    assert_almost_equal(a + b, b + a)
+    assert_almost_equal(a - b, -(b - a))
+    assert_almost_equal(a * b, b * a)
+    assert_almost_equal(b / a, b / a.in_units("km"))
+    assert_almost_equal(a / b, a / b.in_units("km"))
